@@ -1,9 +1,10 @@
+# frozen_string_literal: true
 module Sidekiq
   class JobLogger
 
     def call(item, queue)
       start = Time.now
-      logger.info("start".freeze)
+      logger.info("start")
       yield
       logger.info("done: #{elapsed(start)} sec")
     rescue Exception
